@@ -11,6 +11,7 @@ class CardType:
     DEBIT = 1
     EBT = 2
     GIFT = 3
+    HEALTHCARE = 4
 
 
 class SignatureFormat:
@@ -44,3 +45,28 @@ class AVSResponse:
     ADDRESS_MATCH = "address_match"
     POSTAL_CODE_MATCH = "zip_match"
     ADDRESS_AND_POSTAL_CODE_MATCH = "match"
+
+class CVMType:
+    """Contains customer verification methods."""
+
+    SIGNATURE = "Signature"
+    OFFLINE_PIN = "Offline PIN"
+    ONLINE_PIN = "Online PIN"
+    CDCVM = "CDCVM"
+    NO_CVM = "No CVM"
+
+class HealthcareType:
+    """Contains categories of healthcare amounts."""
+
+    HEALTHCARE = "healthcare"
+    PRESCRIPTION = "prescription"
+    VISION = "vision"
+    CLINIC = "clinic"
+    DENTAL = "dental"
+
+class RoundingMode:
+    """Rounding mode options for fractional pennies."""
+
+    UP = "up"
+    NEAREST = "nearest"
+    DOWN = "down"
